==> datalink-0.1.1.tar.gz: datalink-0.1.1/setup.py <==
from setuptools import setup, find_packages
from os import path
here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='datalink',
    version='0.1.1',

    description=('Create simple interfaces to SQL that make working with data as simple'
                ' as working with dictionaries.'),

    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/hypernormalisation/datalink',
    author='Stephen Ogilvy',
    author_email='sogilvy@protonmail.com',
    classifiers=[
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Database :: Front-Ends',

        # Pick your license as you wish
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        # These classifiers are *not* checked by 'pip install'. See instead
        # 'python_requires' below.
        # 'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.4',
        # 'Programming Language :: Python :: 3.5',
        # 'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],

    # This field adds keywords for your project which will appear on the
    # project page. What does your project relate to?
    keywords='development database sql',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),  # Required

    # Specify which Python versions you support. In contrast to the
    # 'Programming Language' classifiers above, 'pip install' will check this
    # and refuse to install the project if the version does not match. If you
    # do not support Python 2, you can simplify this to '>=3.5' or similar, see
    # https://packaging.python.org/guides/distributing-packages-using-setuptools/#python-requires
    # python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, <4',
    python_requires='>=3.3',
    install_requires=['sqlalchemy',
                      'dataset',
                      'sqlalchemy',
                      'sqlalchemy_utils',
                      'traits'],

    # Examples listed include a pattern for specifying where the package tracks
    # issues, where the source is hosted, where to say thanks to the package
    # maintainers, and where to support the project financially. The key is
    # what's used to render the link text on PyPI.
    # project_urls={  # Optional
    #     'Bug Reports': 'https://github.com/pypa/sampleproject/issues',
    #     'Funding': 'https://donate.pypi.org',
    #     'Say Thanks!': 'http://saythanks.io/to/example',
    #     'Source': 'https://github.com/pypa/sampleproject/',
    # },
)

==> datalink-0.1.2.tar.gz: datalink-0.1.2/setup.py <==
from setuptools import setup, find_packages
from os import path
here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='datalink',
    version='0.1.2',

    description=('Create simple interfaces to SQL that make working with data as simple'
                ' as working with dictionaries.'),

    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/hypernormalisation/datalink',
    author='Stephen Ogilvy',
    author_email='sogilvy@protonmail.com',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Database :: Front-Ends',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],

    keywords='development database sql pandas',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    python_requires='>=3.3',
    install_requires=['sqlalchemy',
                      'dataset',
                      'sqlalchemy',
                      'sqlalchemy_utils',
                      'traits==5.2.0',
                      'pandas'],

    project_urls={
        'Bug Reports': 'https://github.com/hypernormalisation/datalink/issues',
        'Source': 'https://github.com/hypernormalisation/datalink',
    },
)
